@@ -14,6 +14,12 @@ setMethod("getMotionVariance",
 	  definition=function(x,...){
 		  cbind(para=x@paraSd^2, orth=x@orthSd^2)
 	  })
+setMethod("getMotionVariance", 
+	  signature="dBMvarianceBurst",
+	  definition=function(x,...){
+		  x<-as(x,'dBMvarianceTmp')
+		  callGeneric()
+	  })
 setMethod("getMotionVariance", 
 	  signature="DBBMM",
 	  definition=function(x,...){
